#ifndef NT2_INCLUDE_CONSTANTS_TRUE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TRUE_HPP_INCLUDED

#include <nt2/constant/include/constants/true.hpp>

#endif
